**WEIGHT YOUR SURVEY RESPONSES PROPORTIONALLY **
* Before aggregating your RC variables to the site level, consider what kind of weighting you want to do between workgroups - proportional or equal.  Proportional weighting will give each workgroup a weight that is proportional to its size relative to the other workgroups in the same site. *
*Sometimes, for example in case of evaluating a service where all roles play equal part in the work process, proportional weighting which will preserve the sampling distribution of the role in the population, may not be the best option. Equal weighting is another way to give each workgroup an equal weight relative to the other workgroups in the same site. *

**Proportional Weights**
* If you aggregate individual survey responses to the site level, the larger workgroups will naturally be weighted more heavily than the small workgroups.  If you want to preserve this proportional weighting, you will have to correct for differential response rates between workgroups to that each workgroup will be weighted proportional to its size*
*Proportional weights are calculated based on the following equation:

*Wp = Percent of the workgroup's participants from all invited/Percent of the workgroup respondents from all respondents*

*1.0. Create a variable = number of participants who didn't respond to the RC survey*
egen nmis=rmiss(Q1* Q2* Q3* Q4* Q5* Q6* Q7*)
*or*
egen nmis =rmiss(freq* time* accu* prob* goal* know* resp*)

*1.1.first check how many missing observations within each workgroup, in our sample coding the workgroup variable is WG, and nmis is the newly generated missing number in the RC survey `created in the previous step'*
*Then generate the percentages in the following way, where WG is the workgroup variable in numerical form*
tab WG nmis

*then fill in the above Wp's equation*
**Wp=  (A) percent of total target population within each workgroup / (B) percent of respondents within each workgroup**
**first we need to calculate (A): the percent of total target population by workgroup**
**percent of total population by workgroup= number of participants INVITED per workgroup/ total participants INVITED / overall across all workgroups**
** to create the denominator [TInvited]: a variable that has the count of total invited across all workgroups**

egen TInvited = count(ParticipantID )
sum TInvited

**then we generate the nominator [WTInvited], total invited in each of the workgroups**

egen WTInvited = count(ParticipantID), by(WG )

**second  we need to calculate (B): the percent of respondents within each workgroup**
**percent of respondents within each workgroup= number of participants responded per this specific workgroup / overall number of respondents across all workgroups**
** to create the denominator [TRespon]: a variable that has the count of overall number of respondents across all workgroups**

egen TRespon = count(ParticipantID ) if nmis==0
sum TRespon

**then we generate the nominator [WTRespon], number of participants responded per this specific workgroup**

egen WTRespon = count(ParticipantID) if nmis==0, by( WG)

**finally we calculate proportional weights [PW]so that response rate within a workgroup doesn't affect the proposed representation of this group**

generate PW = (WTInvited / TInvited )/(WTRespon/ TRespon)

**here are the codes without the explanatory formulas**
egen TInvited = count(ParticipantID )
sum TInvited
egen WTInvited = count(ParticipantID), by(Workgroup)
egen TRespon = count(ParticipantID ) if nmis==0
sum TRespon
egen WTRespon = count(ParticipantID) if nmis==0, by( WG)
generate PW = (WTInvited / TInvited )/(WTRespon/ TRespon)


***********************************************************************************************************************Equal/custom Weighting
*If instead you want your workgroups to be equally weighted, because you think they equally impact the overall coordination of the work, then you should create equal weights before proceeding further*

*Equal weights are calculated based on the following equation*

**In case you wish to adjust the sample's workgroup to be equally represented, we need to remove the difference in the influence of the workgroup participants' numbers by counting the groups and creating equal weights.
Example: you have 4 workgroups [group A is 100, group B is 50, Group C & D are 25 each]. Without equal weighting, group A rating will shape 50% of the RC and dimensions scores while group C & D will contribute only 12.5% (25/200=0.125) of the total scores.
With equal weights, all groups will contribute 25% each of the aggregated score**


**you need a to install package called EGENMORE to create a variable counting number of your workgroups***

help ssc type egenmore.sthlp
**click on install the latest version**
**create new variable equals total number of groups reported  by your participants**

egen TNWG =  nvals( WG) 

**or if you have different number of workgroups in each site: use this commands**
egen TNWG2 = nvals( WG), by (site)
sum TNWG

** then using the same above commands to create total number of respondents, same  variable used for non-response rate/ proportional weights**

egen TRespon = count(ParticipantID ) if nmis==0
sum TRespon

** then adjust for respondents number in each of the workgroups; to downsize and normalize the workgroups effect**
egen WTRespon = count(ParticipantID) if nmis==0, by (WG)

generate PW2 = (1 / TNWG)/(WTRespon/ TRespon)



